==> bootstrap-styled-redux-0.0.3.tgz: package/lib/components/ThemeToggle/tests/index.test.js <==
'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactRedux = require('react-redux');

var _enzyme = require('enzyme');

var _redux = require('redux');

var _theme = require('bootstrap-styled/lib/theme');

var _theme2 = _interopRequireDefault(_theme);

var _actions = require('../../../actions');

var _reducer = require('../../../reducer');

var _reducer2 = _interopRequireDefault(_reducer);

var _index = require('../index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable function-paren-newline */
describe('<ThemeToggle />', function () {
  var store = void 0;
  beforeAll(function () {
    store = (0, _redux.createStore)(_reducer2.default);
  });

  it('should render the default language messages', function () {
    var renderedComponent = (0, _enzyme.mount)(_react2.default.createElement(
      _reactRedux.Provider,
      { store: store },
      _react2.default.createElement(_index2.default, null)
    ));
    expect(renderedComponent.contains(_react2.default.createElement(_index2.default, null))).toBe(true);
  });

  describe('mapDispatchToProps', function () {
    describe('onThemeToggle', function () {
      it('should be injected', function () {
        var dispatch = jest.fn();
        var result = (0, _index.mapDispatchToProps)(dispatch);
        expect(result.onThemeToggle).toBeDefined();
      });

      it('should dispatch onThemeToggle when called', function () {
        var dispatch = jest.fn();
        var result = (0, _index.mapDispatchToProps)(dispatch);
        var evt = { target: { value: _theme2.default } };
        result.onThemeToggle(evt);
        expect(dispatch).toHaveBeenCalledWith((0, _actions.changeTheme)(_theme2.default));
      });
    });
  });
});

==> bootstrap-styled-redux-0.0.9.tgz: package/lib/components/ThemeToggle/tests/index.test.js <==
'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactRedux = require('react-redux');

var _enzyme = require('enzyme');

var _redux = require('redux');

var _theme = require('bootstrap-styled/lib/theme');

var _theme2 = _interopRequireDefault(_theme);

var _actions = require('../../../actions');

var _reducer = require('../../../reducer');

var _reducer2 = _interopRequireDefault(_reducer);

var _index = require('../index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable function-paren-newline */
describe('<ThemeToggle />', function () {
  var store = void 0;
  beforeAll(function () {
    store = (0, _redux.createStore)(_reducer2.default);
  });

  it('should render the default language messages', function () {
    var renderedComponent = (0, _enzyme.mount)(_react2.default.createElement(
      _reactRedux.Provider,
      { store: store },
      _react2.default.createElement(_index2.default, null)
    ));
    expect(renderedComponent.contains(_react2.default.createElement(_index2.default, null))).toBe(true);
  });

  describe('mapDispatchToProps', function () {
    describe('onToggle', function () {
      it('should be injected', function () {
        var dispatch = jest.fn();
        var result = (0, _index.mapDispatchToProps)(dispatch);
        expect(result.onToggle).toBeDefined();
      });

      it('should dispatch onToggle when called', function () {
        var dispatch = jest.fn();
        var result = (0, _index.mapDispatchToProps)(dispatch);
        var evt = { target: { value: _theme2.default } };
        result.onToggle(evt);
        expect(dispatch).toHaveBeenCalledWith((0, _actions.changeTheme)(_theme2.default));
      });
    });
  });
});
